<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" encoding="UTF-8" />

<xsl:variable name="messages" select="document('ru.xml')/messages"/>
<xsl:variable name="root" select="document('config.xml')/config/root"/>
<!--xsl:variable name="url" select="document('url.xml')/schedule-url"/>-->

<xsl:template match="/trip">
<html>
    <head>
        <link href="{$root}xsl/trip.css" type="text/css" rel="stylesheet" media="all" />
        <title>
	<xsl:choose>
	    <xsl:when test="tripinfo/@name">
		<xsl:value-of select="$messages/message[@name='title']"/>:
		<xsl:value-of select="@name"/>
	    </xsl:when>
	    <xsl:when test="@name">
		<xsl:value-of select="$messages/message[@name='title']"/>:
		<xsl:value-of select="@name"/>
	    </xsl:when>
	    <xsl:otherwise>
		<xsl:value-of select="$messages/message[@name='title']"/>
	    </xsl:otherwise>
	</xsl:choose>
        </title>
    </head>
    <body>
	<xsl:if test='@href'>
	    <table class='title'><tr><td class='title'>
	    <a href="{@href}" class="block">
		<xsl:value-of select="$messages/message[@name='tripinfo']"/>: 
		<xsl:value-of select="@name"/>
	    </a>
	    </td></tr></table>
	</xsl:if>
        <xsl:apply-templates />
	</body>
</html>
</xsl:template>

<xsl:template name='person'>
    <xsl:variable name='nick' select='.'/>
    <xsl:choose>
    <xsl:when test="/trip/teaminfo/guy[@nick=$nick]/name">
	<xsl:value-of select="/trip/teaminfo/guy[@nick=$nick]/name"/>
    </xsl:when>
    <xsl:otherwise>
	<xsl:value-of select='$nick'/>
    </xsl:otherwise>
    </xsl:choose>
    <xsl:if test="@comment">
	<xsl:text> (</xsl:text>
	<xsl:value-of select="@comment"/>
	<xsl:text>)</xsl:text>
    </xsl:if>
</xsl:template>

<xsl:template name='weight-suffix'>
    <xsl:text> </xsl:text>
    <xsl:choose>
    <xsl:when test="weight/@item">
	<xsl:value-of select="weight/@item"/>
    </xsl:when>
    <xsl:otherwise>
	<xsl:value-of select="$messages/message[@name='kilogramm']"/>
    </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template name='weight'>
    <xsl:choose>
    <xsl:when test="@weight != ''"> 
	<xsl:value-of select="@weight"/>
	<xsl:call-template name='weight-suffix'/>
    </xsl:when>
    <xsl:when test="weight"> 
	<xsl:value-of select="weight"/>
	<xsl:variable name='tmp' select='weight'/>
	<xsl:if test="$tmp != ''">
	    <xsl:call-template name='weight-suffix'/>
	</xsl:if>
    </xsl:when>
    <xsl:when test="sum != ''">
	<xsl:value-of select="sum"/>
	<xsl:call-template name='weight-suffix'/>
    </xsl:when>
    <xsl:otherwise>
	<xsl:text></xsl:text>
    </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="info">
    <table class="tripinfo">
    <xsl:if test="@location"> 
    <tr>
        <td class="st-variable"><xsl:value-of select="$messages/message[@name='location']"/></td>
        <td class="st-value"><xsl:value-of select="@location"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="@date"> 
    <tr>
        <td class="st-variable"><xsl:value-of select="$messages/message[@name='date']"/></td>
	<td class="st-value"><xsl:value-of select="@date"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="@type"> 
    <tr>
        <td class="st-variable"><xsl:value-of select="$messages/message[@name='type']"/></td>
	<td class="st-value"><xsl:value-of select="@type"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="@people"> 
    <tr>
        <td class="st-variable"><xsl:value-of select="$messages/message[@name='people']"/></td>
	<td class="st-value"><xsl:value-of select="@people"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="@duration"> 
    <tr>
        <td class="st-variable"><xsl:value-of select="$messages/message[@name='duration']"/></td>
	<td class="st-value"><xsl:value-of select="@duration"/></td>
    </tr>
    </xsl:if>
    <xsl:if test="@author"> 
    <tr>
        <td class="st-variable"><xsl:value-of select="$messages/message[@name='author']"/></td>
	<td class="st-value"><xsl:value-of select="@author"/></td>
    </tr>
    </xsl:if>
    </table>
    <br/>
</xsl:template>

<xsl:include href='foodinfo.xsl'/>
<xsl:include href='gearinfo.xsl'/>
<xsl:include href='teaminfo.xsl'/>
<xsl:include href='trackinfo.xsl'/>
</xsl:stylesheet>
